import type { PredIndexed } from "./_types";
/**
 * Returns the max element using the provided predicate.
 *
 * If you need more control over how "max" is defined, consider using `firstBy` instead. `maxBy` might be deprecated in the future!
 *
 * @param fn - The predicate.
 * @signature
 *    R.maxBy(fn)(array)
 *    R.maxBy.indexed(fn)(array)
 * @example
 *    R.pipe(
 *      [{a: 5}, {a: 1}, {a: 3}],
 *      R.maxBy(x => x.a)
 *    ) // { a: 5 }
 * @dataLast
 * @indexed
 * @category Array
 */
export declare function maxBy<T>(fn: (item: T) => number): (items: ReadonlyArray<T>) => T | undefined;
/**
 * Returns the max element using the provided predicate.
 *
 * @param items - The array.
 * @param fn - The predicate.
 * @signature
 *    R.maxBy(array, fn)
 *    R.maxBy.indexed(array, fn)
 * @example
 *    R.maxBy(
 *      [{a: 5}, {a: 1}, {a: 3}],
 *      x => x.a
 *    ) // { a: 5 }
 * @dataFirst
 * @indexed
 * @category Array
 */
export declare function maxBy<T>(items: ReadonlyArray<T>, fn: (item: T) => number): T | undefined;
export declare namespace maxBy {
    function indexed<T>(array: ReadonlyArray<T>, fn: PredIndexed<T, number>): T | undefined;
    function indexed<T>(fn: PredIndexed<T, number>): (array: ReadonlyArray<T>) => T | undefined;
}
//# sourceMappingURL=maxBy.d.ts.map